==> nextcloud-31.0.9.tar.bz2: nextcloud/apps/circles/l10n/be.js <==
OC.L10N.register(
    "circles",
    {
    "Teams" : "Каманды",
    "You created the team {circle}" : "Вы стварылі каманду {circle}",
    "{author} created the team {circle}" : "{author} стварыў(-ла) каманду {circle}",
    "You deleted {circle}" : "Вы выдалілі {circle}",
    "{author} deleted {circle}" : "{author} выдаліў(-ла) {circle}",
    "You made {member} join {circle}" : "Вы зрабілі так, каб карыстальнік {member} далучыўся да {circle}",
    "{author} made {member} join {circle}" : "{author} зрабіў(-ла) так, каб карыстальнік {member} далучыўся да {circle}",
    "You made {member} leave {circle}" : "Вы зрабілі так, каб карыстальнік {member} выйшаў з {circle}",
    "{author} made {member} leave {circle}" : "{author} зрабіў(-ла) так, каб карыстальнік {member} выйшаў з {circle}",
    "You removed {member} from {circle}" : "Вы выдалілі {member} з {circle}",
    "{author} removed {member} from {circle}" : "{author} выдаліў(-ла) {member} з {circle}",
    "You joined {circle}" : "Вы далучыліся да {circle}",
    "{member} joined {circle}" : "{member} далучыўся(-лася) да {circle}",
    "You accepted the invitation to join {circle}" : "Вы прынялі запрашэнне далучыцца да {circle}",
    "{member} accepted the invitation to join {circle}" : "{member} прыняў(-ла) запрашэнне далучыцца да {circle}",
    "You added {member} as member to {circle}" : "Вы дадалі {member} да {circle}",
    "You have been added as member to {circle} by {author}" : "{author} дадаў(-ла) вас да {circle}",
    "{member} has been added as member to {circle} by {author}" : "{author} дадаў(-ла) {member} да {circle}",
    "You added {external} to {circle}" : "Вы дадалі {external} да {circle}",
    "{external} has been added to {circle} by {author}" : "{author} дадаў(-ла) {external} да {circle}",
    "You left {circle}" : "Вы выйшлі з {circle}",
    "{member} left {circle}" : "{member} выйшаў(-ла) з {circle}",
    "You removed {external} from {circle}" : "Вы выдалілі {external} з {circle}",
    "Open" : "Адкрыць",
    "Invite" : "Запрасіць",
    "Friends" : "Сябры",
    "Federated" : "Федэратыўны",
    "Nextcloud Account" : "Уліковы запіс Nextcloud",
    "Nextcloud Group" : "Група Nextcloud",
    "Email address" : "Адрас электроннай пошты",
    "Contact" : "Кантакт",
    "Team" : "Каманда",
    "Nextcloud App" : "Праграма Nextcloud",
    "Member" : "Удзельнік",
    "Moderator" : "Мадэратар",
    "Admin" : "Адміністратар",
    "Owner" : "Уладальнік",
    "Circles App Initialization" : "Ініцыялізацыя праграмы Кругі",
    "Create a new team" : "Стварыць новую каманду",
    "Files" : "Файлы",
    "Accept" : "Прыняць",
    "Leave the team" : "Выйсці з каманды",
    "%s" : "%s",
    "You have no permission to create a new team" : "У вас няма дазволу на стварэнне новай каманды",
    "Open %s" : "Адкрыць %s",
    "Failed to load teams" : "Не ўдалося загрузіць каманды",
    "Try again" : "Паспрабаваць яшчэ раз",
    "No teams found" : "Каманд не знойдзена",
    "Create your first team" : "Стварыце сваю першую каманду",
    "Loading…" : "Загрузка…",
    "No files in here" : "Тут няма файлаў",
    "No entries found in this folder" : "У гэтай папцы не знойдзена запісаў",
    "Name" : "Назва",
    "Size" : "Памер",
    "Modified" : "Зменены",
    "Teams' files" : "Файлы каманд",
    "Circle" : "Круг"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");

==> nextcloud-32.0.1rc1.tar.bz2: nextcloud/apps/circles/l10n/be.js <==
OC.L10N.register(
    "circles",
    {
    "Teams" : "Каманды",
    "You created the team {circle}" : "Вы стварылі каманду {circle}",
    "{author} created the team {circle}" : "{author} стварыў(-ла) каманду {circle}",
    "You deleted {circle}" : "Вы выдалілі {circle}",
    "{author} deleted {circle}" : "{author} выдаліў(-ла) {circle}",
    "You made {member} join {circle}" : "Вы зрабілі так, каб карыстальнік {member} далучыўся да {circle}",
    "{author} made {member} join {circle}" : "{author} зрабіў(-ла) так, каб карыстальнік {member} далучыўся да {circle}",
    "You made {member} leave {circle}" : "Вы зрабілі так, каб карыстальнік {member} выйшаў з {circle}",
    "{author} made {member} leave {circle}" : "{author} зрабіў(-ла) так, каб карыстальнік {member} выйшаў з {circle}",
    "You removed {member} from {circle}" : "Вы выдалілі {member} з {circle}",
    "{author} removed {member} from {circle}" : "{author} выдаліў(-ла) {member} з {circle}",
    "You joined {circle}" : "Вы далучыліся да {circle}",
    "{member} joined {circle}" : "{member} далучыўся(-лася) да {circle}",
    "You accepted the invitation to join {circle}" : "Вы прынялі запрашэнне далучыцца да {circle}",
    "{member} accepted the invitation to join {circle}" : "{member} прыняў(-ла) запрашэнне далучыцца да {circle}",
    "You added {member} as member to {circle}" : "Вы дадалі {member} да {circle}",
    "You have been added as member to {circle} by {author}" : "{author} дадаў(-ла) вас да {circle}",
    "{member} has been added as member to {circle} by {author}" : "{author} дадаў(-ла) {member} да {circle}",
    "You added {external} to {circle}" : "Вы дадалі {external} да {circle}",
    "{external} has been added to {circle} by {author}" : "{author} дадаў(-ла) {external} да {circle}",
    "You left {circle}" : "Вы выйшлі з {circle}",
    "{member} left {circle}" : "{member} выйшаў(-ла) з {circle}",
    "You removed {external} from {circle}" : "Вы выдалілі {external} з {circle}",
    "Personal" : "Асабістыя",
    "System" : "Сістэма",
    "Open" : "Адкрыць",
    "Invite" : "Запрасіць",
    "Friends" : "Сябры",
    "Local" : "Лакальна",
    "Root" : "Корань",
    "Federated" : "Федэратыўны",
    "Nextcloud Account" : "Уліковы запіс Nextcloud",
    "Nextcloud Group" : "Група Nextcloud",
    "Email address" : "Адрас электроннай пошты",
    "Contact" : "Кантакт",
    "Team" : "Каманда",
    "Nextcloud App" : "Праграма Nextcloud",
    "Teams App" : "Праграма Каманды",
    "Admin Command Line" : "Камандны радок адміністратара",
    "Member" : "Удзельнік",
    "Moderator" : "Мадэратар",
    "Admin" : "Адміністратар",
    "Owner" : "Уладальнік",
    "%1$s via %2$s" : "%1$s праз %2$s",
    "Circles App Initialization" : "Ініцыялізацыя праграмы Кругі",
    "Create a new team" : "Стварыць новую каманду",
    "Files" : "Файлы",
    "Accept" : "Прыняць",
    "Leave the team" : "Выйсці з каманды",
    "%s" : "%s",
    "You have no permission to create a new team" : "У вас няма дазволу на стварэнне новай каманды",
    "Open %s" : "Адкрыць %s",
    "Failed to load teams" : "Не ўдалося загрузіць каманды",
    "Try again" : "Паспрабаваць яшчэ раз",
    "No teams found" : "Каманд не знойдзена",
    "Create your first team" : "Стварыце сваю першую каманду",
    "Loading…" : "Загрузка…",
    "No files in here" : "Тут няма файлаў",
    "No entries found in this folder" : "У гэтай папцы не знойдзена запісаў",
    "Name" : "Назва",
    "Size" : "Памер",
    "Modified" : "Зменены",
    "Circle" : "Круг"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
